#
# spec file for package gum
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global _lto_cflags %nil
Name:           gum
Version:        0.15.2
Release:        1.1
Summary:        Tool for glamorous shell scripts
License:        MIT
URL:            https://github.com/charmbracelet/gum
Source0:        https://github.com/charmbracelet/gum/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  zstd
BuildRequires:  golang(API)

%description
Gum leverages the power of Bubbles and Lip Gloss in your scripts and aliases.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and bash-completion)
Requires:       bash-completion
BuildArch:      noarch

%description bash-completion
Bash command-line completion support for %{name}.

%package fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and fish)
Requires:       fish
BuildArch:      noarch

%description fish-completion
Fish command-line completion support for %{name}.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and zsh)
Requires:       zsh
BuildArch:      noarch

%description zsh-completion
Zsh command-line completion support for %{name}.

%prep
%autosetup -a1

%build
%ifarch ppc64
BUILDMOD=""
%else
BUILDMOD="-buildmode=pie"
%endif
export CGO_CFLAGS="%{optflags}"
export CGO_CXXFLAGS="%{optflags}"
export CGO_CPPFLAGS="%{optflags}"
go build -v -x -mod=vendor $BUILDMOD -a -ldflags "-s -X main.Version=%{version}"

%install
install -Dm755 %{name} %{buildroot}%{_bindir}/%{name}

# Completions
for sh in bash zsh fish; do
  ./%{name} completion $sh > %{name}.${sh}
done
install -Dm644 %{name}.bash %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -Dm644 %{name}.zsh %{buildroot}%{_datadir}/zsh/site-functions/_%{name}
install -Dm644 %{name}.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/%{name}.fish

%files
%{_bindir}/%{name}
%license LICENSE
%doc README.md

%files bash-completion
%{_datadir}/bash-completion/*

%files fish-completion
%dir %{_datadir}/fish
%{_datadir}/fish/*

%files zsh-completion
%dir %{_datadir}/zsh
%{_datadir}/zsh/*

%changelog
* Sat Feb  1 2025 Joshua Smith <smolsheep@opensuse.org>
- Update to 0.15.2:
  Fixes
  * fix(pager): memory/cpu usage when using soft-wrap
- Updates from 0.15.1:
  * Revert "feat(table): set --print if stdout is not a terminal"
  * fix(confirm): do not print 'not confirmed' on exit 1
  * fix(filter): wrong highlight when option has grapheme clusters
  * fix(spin): clear title after finished
  * fix(viewport): remove extra line in viewport help
  * fix(write): ctrl+j not making new line
  * fix: spin when not a tty
* Sun Jan 19 2025 Joshua Smith <smolsheep@opensuse.org>
- Update to 0.15.0:
  New
  * feat(choose): --selected="*" to select all
  * feat(choose,filter): --input-delimiter --output-delimiter
  * feat(confirm): add --show-output
  * feat(file): add --header
  * feat(file): show permissions and size
  * feat(filter): --select-if-one returns if single match
  * feat(filter): allow to focus out of filter
  * feat(filter): allow to pre-select items with --selected
  * feat(filter): ctrl+a to toggle select all
  * feat(log): support setting minimum log level with GUM_LOG_LEVEL
  * feat(spin): --show-stdout --show-stderr
  * feat(style): trim line spaces
  * feat(table): --lazy-quotes and --fields-per-record
  * feat(table): add help
  * feat(table): set --print if stdout is not a terminal
  * feat(version): adds command to check current gum version
  * feat: adding return column to table command
  * feat: allow cursor option in file
  * feat: esc exit 1, ctrl+c exit 130, help arrow order
  * feat: handle focus/blur events
  * feat: improve handling ctrl+c and timeouts
  Fixed
  * fix(choose): --ordered
  * fix(choose,confirm,file,filter,input,pager,spin): timeout
    default unit
  * fix(confirm) --timeout was ignored, now works as documented
  * fix(confirm,choose,file,input): timeout handling
  * fix(filter): --no-strict not working, also weird behavior
  * fix(filter): abort on ctrl+q
  * fix(pager): do not strip ansi sequences
  * fix(pager): use help bubble
  * fix(spin): if not a tty, only print title, do not open tty for
    stdin
  * fix(spin): indenting lines when command is piped
  * fix(spin): interrupt child process on ctrl+c
  * fix(stdin): trim space instead of \n
  * fix(table): grow table rows based on --columns
  * fix(table): ignore BOM
  * fix(table): only set height if > 0
  * fix(table): set widths
  * fix(write): max height, max chars
  * fix: clarify filter --sort flag
  * fix: strip ansi sequences from stdin
  * fix: quote tmux session name in code sample
  Other Stuff
  * refactor: removing huh as a dep
* Sun Sep 29 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to 0.14.5:
  * Dependency bump
  Bug fixes
  * fix: lint issues
* Sat Aug 24 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to 0.14.4:
  New
  * Add cyclic navigation
  Fixed
  * wrong height when using borders in the header
  * height 0 by default
  * use 0 as default width
  * select all keybindings
  * show background style help
  Docs
  * update install instructions
* Thu Jul 25 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to 0.14.3:
  * revert "fix: pause tea before running the sub-process"
- Updates from 0.14.2:
  Changed
  * use in-house utility packages
  Fixed
  * drop left padding in choose
  * fix race conditon where spinner could mis-render
  * fix a bug where choose could crash when spacebar is pressed
    twice
  * fix a bug where the foreground color could not be set in choose
  * fix a bug where foreground could not be set in write
  * fix a bug where keypresses could crash choose
  * restore y/n keybindings to confirm
  * restore centering to buttons in confirm
* Thu Jul 11 2024 Joshua Smith <smolsheep@opensuse.org>
- Switch from deprecated %%setup to %%autosetup
- Update to 0.14.1:
  New:
  * Show help with Huh?
  * Support using the Home/End keys in pager
  Fixes:
  * Handle huh? user aborted error
  * Cursor styling
  * Re-introduce ESC for gum write
* Sun Apr 28 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to 0.14.0:
  New:
  * Use Huh for choose, confirm, file, input and write
  * Add support for `--show-error` for the spinner.
  Fixes:
  * don't commit filter.tape
  * Output Pipes if Timeout Occurs
  Documentation:
  * add new gifs such as spin.gif
  * add help for `gum log --time` option
* Wed Feb 14 2024 Joshua Smith <jsmithfpv@gmail.com>
- Enabled completions for bash, zsh and fish.
* Tue Jan 16 2024 Joshua Smith <jsmithfpv@gmail.com>
- Update to 0.13.0:
  New:
  * Add --select-if-one flag to gum choose and gum filter
  * Added brand new log command. Gum log logs messages to the
    terminal at different levels and styling
  * Pager search functionality
  * Strip ANSI for gum filter and gum choose when output is not
    a TTY
  * Non-positive widths will cause gum write will use the entire
    terminal width
  * GUM_FORMAT_THEME / GUM_FORMAT_LANGUAGE environment variables
  * --no-sort flag for gum filter
  * Customizable cursor modes and line text
  * Add --timeout flag to all subcommands
  * Truecolor support added to gum style
  * Context headers for gum choose and gum filter
  * Keep order of selected items in gum choose with --ordered
  * Pass programming language for gum format
  * Customize format theme, including using glamour json theme
    files
  * gum choose now supports tab and ctrl+j/k keybindings
  * add --file and --directory flags to select each in gum file
  * gum pager --soft-wrap option added
  * gum style pass input to style over stdin
  * ability to add --header values
  Fixes:
  * showoutput flag displays in realtime
  * Pretty Table Print improved
  * Avoid reading from stdin if --value is being used
  * Made filter work with losts as choose
  * Respect file path argument in filepicker
  * --all option defaults to false
  * exit with status 130 if escape key pressed on gum write
  * symlink directory follows link in gum file
  * allow exact match in gum filter
* Fri Feb 17 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for gum 0.8.0
